IntoBufferReader

Trait IntoBufferReader 

pub trait IntoBufferReader<B> {
    // Required method
    fn into_buffer_reader(self) -> BufferReader<B>;
}
Types that can be converted into a BufferReader over a ByteSlice.

Both BufferReader and ByteSlice types implement this trait and it can be used to accept both byte slices and readers.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors