pub enum Bandwidth {
Cbw20,
Cbw40,
Cbw40Below,
Cbw80,
Cbw160,
Cbw80P80 {
vht_secondary_80_channel: u8,
},
}Expand description
Channel bandwidth. Cbw80P80 requires the specification of channel index corresponding to the center frequency of the secondary consecutive frequency segment.
Variants
Implementations