primary_channel_from_freq

Function primary_channel_from_freq 

pub fn primary_channel_from_freq(freq: u32) -> Option<u8>
Converts a 20MHz primary channel center frequency in MHz to a channel number. Returns an error if the frequency does not correspond to the center frequency of a valid standard channel in the 2.4GHz or 5GHz bands.