pub trait Intersect {
// Required method
fn intersect(&self, other: &Self) -> Self;
}Expand description
Intersect capabilities between two entities, such as a client and an AP. Note: a.intersect(b) is not guaranteed to be the same as b.intersect(b). One such example is the TX_STBC and RX_STBC fields in HtCapabilityInfo.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".